@@ -10,9 +10,12 @@ import qualified Poly1305
 import qualified Salsa
 import qualified ChaCha
 import qualified ChaChaPoly1305
+import qualified KAT_CMAC
 import qualified KAT_HMAC
+import qualified KAT_HKDF
 import qualified KAT_PBKDF2
 import qualified KAT_Curve25519
+import qualified KAT_Ed448
 import qualified KAT_Ed25519
 import qualified KAT_PubKey
 import qualified KAT_Scrypt
@@ -33,15 +36,18 @@ tests = testGroup "cryptonite"
     , Padding.tests
     , testGroup "MAC"
         [ Poly1305.tests
+        , KAT_CMAC.tests
         , KAT_HMAC.tests
         ]
     , KAT_Curve25519.tests
+    , KAT_Ed448.tests
     , KAT_Ed25519.tests
     , KAT_PubKey.tests
     , testGroup "KDF"
         [ KAT_PBKDF2.tests
         , KAT_Scrypt.tests
         , BCrypt.tests
+        , KAT_HKDF.tests
         ]
     , testGroup "block-cipher"
         [ KAT_AES.tests
